/*
 * Copyright (c) 2011 Michael Schierl
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *   
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *   
 * - Neither name of the copyright holders nor the names of its
 *   contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *   
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND THE CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR THE CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.sf.jmatchparser.util.charset.icu4jchardet;

import java.nio.charset.Charset;
import java.nio.charset.spi.CharsetProvider;
import java.util.Arrays;
import java.util.Iterator;

import com.ibm.icu.text.CharsetDetector;

/**
 * Charset provider that provides a convenience charset that uses <a
 * href="http://icu-project.org/">ICU4J</a> to dynamically detect the charset it
 * uses for decoding.
 * 
 * <p>
 * The name of this charset is "<tt>ICU4J-Chardet</tt>".
 * 
 * <p>
 * This class is loaded automatically via SPI when it is in the class path.
 * 
 * @see CharsetDetector#getAllDetectableCharsets()
 */
public class ICU4JChardetCharsetProvider extends CharsetProvider {

	@Override
	public Charset charsetForName(String charsetName) {
		if (charsetName.equals(ICU4JChardetCharset.NAME))
			return ICU4JChardetCharset.getInstance();
		if (charsetName.equals(ICU4JChardetCharset.FILTERED_NAME))
			return ICU4JChardetCharset.getFilteredInstance();
		return null;
	}

	@Override
	public Iterator<Charset> charsets() {
		return Arrays.asList(new Charset[] { ICU4JChardetCharset.getInstance(), ICU4JChardetCharset.getFilteredInstance() }).iterator();
	}
}
